@@ -35,9 +35,9 @@ from web3._utils.ens import (
 )
 from web3.exceptions import (
     BlockNotFound,
+    ContractLogicError,
     InvalidAddress,
     NameNotFound,
-    SolidityError,
     TransactionNotFound,
 )
 from web3.types import (  # noqa: F401
@@ -59,8 +59,15 @@ if TYPE_CHECKING:
 
 
 class EthModuleTest:
+    def test_eth_protocol_version(self, web3: "Web3") -> None:
+        protocol_version = web3.eth.protocol_version
+
+        assert is_string(protocol_version)
+        assert protocol_version.isdigit()
+
     def test_eth_protocolVersion(self, web3: "Web3") -> None:
-        protocol_version = web3.eth.protocolVersion
+        with pytest.warns(DeprecationWarning):
+            protocol_version = web3.eth.protocolVersion
 
         assert is_string(protocol_version)
         assert protocol_version.isdigit()
@@ -95,13 +102,25 @@ class EthModuleTest:
         assert is_integer(hashrate)
         assert hashrate >= 0
 
-    def test_eth_chainId(self, web3: "Web3") -> None:
-        chain_id = web3.eth.chainId
+    def test_eth_chain_id(self, web3: "Web3") -> None:
+        chain_id = web3.eth.chain_id
         # chain id value from geth fixture genesis file
         assert chain_id == 131277322940537
 
-    def test_eth_gasPrice(self, web3: "Web3") -> None:
-        gas_price = web3.eth.gasPrice
+    def test_eth_chainId(self, web3: "Web3") -> None:
+        with pytest.warns(DeprecationWarning):
+            chain_id = web3.eth.chainId
+        # chain id value from geth fixture genesis file
+        assert chain_id == 131277322940537
+
+    def test_eth_gas_price(self, web3: "Web3") -> None:
+        gas_price = web3.eth.gas_price
+        assert is_integer(gas_price)
+        assert gas_price > 0
+
+    def test_eth_gasPrice_deprecated(self, web3: "Web3") -> None:
+        with pytest.warns(DeprecationWarning):
+            gas_price = web3.eth.gasPrice
         assert is_integer(gas_price)
         assert gas_price > 0
 
@@ -116,26 +135,45 @@ class EthModuleTest:
         ))
         assert web3.eth.coinbase in accounts
 
-    def test_eth_blockNumber(self, web3: "Web3") -> None:
-        block_number = web3.eth.blockNumber
+    def test_eth_block_number(self, web3: "Web3") -> None:
+        block_number = web3.eth.block_number
         assert is_integer(block_number)
         assert block_number >= 0
 
-    def test_eth_getBalance(self, web3: "Web3") -> None:
+    def test_eth_blockNumber(self, web3: "Web3") -> None:
+        with pytest.warns(DeprecationWarning):
+            block_number = web3.eth.blockNumber
+
+        assert is_integer(block_number)
+        assert block_number >= 0
+
+    def test_eth_get_balance(self, web3: "Web3") -> None:
         coinbase = web3.eth.coinbase
 
         with pytest.raises(InvalidAddress):
-            web3.eth.getBalance(ChecksumAddress(HexAddress(HexStr(coinbase.lower()))))
+            web3.eth.get_balance(ChecksumAddress(HexAddress(HexStr(coinbase.lower()))))
 
-        balance = web3.eth.getBalance(coinbase)
+        balance = web3.eth.get_balance(coinbase)
 
         assert is_integer(balance)
         assert balance >= 0
 
-    def test_eth_getBalance_with_block_identifier(self, web3: "Web3") -> None:
-        miner_address = web3.eth.getBlock(1)['miner']
-        genesis_balance = web3.eth.getBalance(miner_address, 0)
-        later_balance = web3.eth.getBalance(miner_address, 1)
+    def test_eth_getBalance_deprecated(self, web3: "Web3") -> None:
+        coinbase = web3.eth.coinbase
+
+        with pytest.warns(DeprecationWarning):
+            with pytest.raises(InvalidAddress):
+                web3.eth.getBalance(ChecksumAddress(HexAddress(HexStr(coinbase.lower()))))
+
+            balance = web3.eth.getBalance(coinbase)
+
+        assert is_integer(balance)
+        assert balance >= 0
+
+    def test_eth_get_balance_with_block_identifier(self, web3: "Web3") -> None:
+        miner_address = web3.eth.get_block(1)['miner']
+        genesis_balance = web3.eth.get_balance(miner_address, 0)
+        later_balance = web3.eth.get_balance(miner_address, 1)
 
         assert is_integer(genesis_balance)
         assert is_integer(later_balance)
@@ -145,35 +183,42 @@ class EthModuleTest:
         ('test-address.eth', True),
         ('not-an-address.eth', False)
     ])
-    def test_eth_getBalance_with_ens_name(
+    def test_eth_get_balance_with_ens_name(
         self, web3: "Web3", address: ChecksumAddress, expect_success: bool
     ) -> None:
         with ens_addresses(web3, {'test-address.eth': web3.eth.accounts[0]}):
             if expect_success:
-                balance = web3.eth.getBalance(address)
+                balance = web3.eth.get_balance(address)
                 assert is_integer(balance)
                 assert balance >= 0
             else:
                 with pytest.raises(NameNotFound):
-                    web3.eth.getBalance(address)
+                    web3.eth.get_balance(address)
 
-    def test_eth_getStorageAt(
+    def test_eth_get_storage_at(
         self, web3: "Web3", emitter_contract_address: ChecksumAddress
     ) -> None:
-        storage = web3.eth.getStorageAt(emitter_contract_address, 0)
+        storage = web3.eth.get_storage_at(emitter_contract_address, 0)
         assert isinstance(storage, HexBytes)
 
-    def test_eth_getStorageAt_ens_name(
+    def test_eth_getStorageAt_deprecated(
+        self, web3: "Web3", emitter_contract_address: ChecksumAddress
+    ) -> None:
+        with pytest.warns(DeprecationWarning):
+            storage = web3.eth.getStorageAt(emitter_contract_address, 0)
+        assert isinstance(storage, HexBytes)
+
+    def test_eth_get_storage_at_ens_name(
         self, web3: "Web3", emitter_contract_address: ChecksumAddress
     ) -> None:
         with ens_addresses(web3, {'emitter.eth': emitter_contract_address}):
-            storage = web3.eth.getStorageAt('emitter.eth', 0)
+            storage = web3.eth.get_storage_at('emitter.eth', 0)
             assert isinstance(storage, HexBytes)
 
-    def test_eth_getStorageAt_invalid_address(self, web3: "Web3") -> None:
+    def test_eth_get_storage_at_invalid_address(self, web3: "Web3") -> None:
         coinbase = web3.eth.coinbase
         with pytest.raises(InvalidAddress):
-            web3.eth.getStorageAt(ChecksumAddress(HexAddress(HexStr(coinbase.lower()))), 0)
+            web3.eth.get_storage_at(ChecksumAddress(HexAddress(HexStr(coinbase.lower()))), 0)
 
     def test_eth_getTransactionCount(
         self, web3: "Web3", unlocked_account_dual_type: ChecksumAddress
@@ -198,7 +243,7 @@ class EthModuleTest:
     def test_eth_getBlockTransactionCountByHash_empty_block(
         self, web3: "Web3", empty_block: BlockData
     ) -> None:
-        transaction_count = web3.eth.getBlockTransactionCount(empty_block['hash'])
+        transaction_count = web3.eth.get_block_transaction_count(empty_block['hash'])
 
         assert is_integer(transaction_count)
         assert transaction_count == 0
@@ -206,7 +251,7 @@ class EthModuleTest:
     def test_eth_getBlockTransactionCountByNumber_empty_block(
         self, web3: "Web3", empty_block: BlockData
     ) -> None:
-        transaction_count = web3.eth.getBlockTransactionCount(empty_block['number'])
+        transaction_count = web3.eth.get_block_transaction_count(empty_block['number'])
 
         assert is_integer(transaction_count)
         assert transaction_count == 0
@@ -214,7 +259,7 @@ class EthModuleTest:
     def test_eth_getBlockTransactionCountByHash_block_with_txn(
         self, web3: "Web3", block_with_txn: BlockData
     ) -> None:
-        transaction_count = web3.eth.getBlockTransactionCount(block_with_txn['hash'])
+        transaction_count = web3.eth.get_block_transaction_count(block_with_txn['hash'])
 
         assert is_integer(transaction_count)
         assert transaction_count >= 1
@@ -222,46 +267,98 @@ class EthModuleTest:
     def test_eth_getBlockTransactionCountByNumber_block_with_txn(
         self, web3: "Web3", block_with_txn: BlockData
     ) -> None:
-        transaction_count = web3.eth.getBlockTransactionCount(block_with_txn['number'])
+        transaction_count = web3.eth.get_block_transaction_count(block_with_txn['number'])
+
+        assert is_integer(transaction_count)
+        assert transaction_count >= 1
+
+    def test_eth_getBlockTransactionCountByHash_block_with_txn_deprecated(
+        self, web3: "Web3", block_with_txn: BlockData
+    ) -> None:
+        with pytest.warns(
+            DeprecationWarning,
+            match="getBlockTransactionCount is deprecated in favor of get_block_transaction_count"
+        ):
+            transaction_count = web3.eth.getBlockTransactionCount(block_with_txn['hash'])
+
+        assert is_integer(transaction_count)
+        assert transaction_count >= 1
+
+    def test_eth_getBlockTransactionCountByNumber_block_with_txn_deprecated(
+        self, web3: "Web3", block_with_txn: BlockData
+    ) -> None:
+        with pytest.warns(
+            DeprecationWarning,
+            match="getBlockTransactionCount is deprecated in favor of get_block_transaction_count"
+        ):
+            transaction_count = web3.eth.getBlockTransactionCount(block_with_txn['number'])
 
         assert is_integer(transaction_count)
         assert transaction_count >= 1
 
     def test_eth_getUncleCountByBlockHash(self, web3: "Web3", empty_block: BlockData) -> None:
-        uncle_count = web3.eth.getUncleCount(empty_block['hash'])
+        uncle_count = web3.eth.get_uncle_count(empty_block['hash'])
+
+        assert is_integer(uncle_count)
+        assert uncle_count == 0
+
+    def test_eth_getUncleCountByBlockHash_deprecated(self,
+                                                     web3: "Web3",
+                                                     empty_block: BlockData) -> None:
+        with pytest.warns(DeprecationWarning,
+                          match='getUncleCount is deprecated in favor of get_uncle_count'):
+            uncle_count = web3.eth.getUncleCount(empty_block['hash'])
 
         assert is_integer(uncle_count)
         assert uncle_count == 0
 
     def test_eth_getUncleCountByBlockNumber(self, web3: "Web3", empty_block: BlockData) -> None:
-        uncle_count = web3.eth.getUncleCount(empty_block['number'])
+        uncle_count = web3.eth.get_uncle_count(empty_block['number'])
 
         assert is_integer(uncle_count)
         assert uncle_count == 0
 
-    def test_eth_getCode(self, web3: "Web3", math_contract_address: ChecksumAddress) -> None:
-        code = web3.eth.getCode(math_contract_address)
+    def test_eth_getUncleCountByBlockNumber_deprecated(self,
+                                                       web3: "Web3",
+                                                       empty_block: BlockData) -> None:
+        with pytest.warns(DeprecationWarning,
+                          match='getUncleCount is deprecated in favor of get_uncle_count'):
+            uncle_count = web3.eth.getUncleCount(empty_block['number'])
+
+        assert is_integer(uncle_count)
+        assert uncle_count == 0
+
+    def test_eth_get_code(self, web3: "Web3", math_contract_address: ChecksumAddress) -> None:
+        code = web3.eth.get_code(math_contract_address)
         assert isinstance(code, HexBytes)
         assert len(code) > 0
 
-    def test_eth_getCode_ens_address(
+    def test_eth_getCode_deprecated(self,
+                                    web3: "Web3",
+                                    math_contract_address: ChecksumAddress) -> None:
+        with pytest.warns(DeprecationWarning, match='getCode is deprecated in favor of get_code'):
+            code = web3.eth.getCode(math_contract_address)
+        assert isinstance(code, HexBytes)
+        assert len(code) > 0
+
+    def test_eth_get_code_ens_address(
         self, web3: "Web3", math_contract_address: ChecksumAddress
     ) -> None:
         with ens_addresses(
             web3, {'mathcontract.eth': math_contract_address}
         ):
-            code = web3.eth.getCode('mathcontract.eth')
+            code = web3.eth.get_code('mathcontract.eth')
             assert isinstance(code, HexBytes)
             assert len(code) > 0
 
-    def test_eth_getCode_invalid_address(self, web3: "Web3", math_contract: "Contract") -> None:
+    def test_eth_get_code_invalid_address(self, web3: "Web3", math_contract: "Contract") -> None:
         with pytest.raises(InvalidAddress):
-            web3.eth.getCode(ChecksumAddress(HexAddress(HexStr(math_contract.address.lower()))))
+            web3.eth.get_code(ChecksumAddress(HexAddress(HexStr(math_contract.address.lower()))))
 
-    def test_eth_getCode_with_block_identifier(
+    def test_eth_get_code_with_block_identifier(
         self, web3: "Web3", emitter_contract: "Contract"
     ) -> None:
-        code = web3.eth.getCode(emitter_contract.address, block_identifier=web3.eth.blockNumber)
+        code = web3.eth.get_code(emitter_contract.address, block_identifier=web3.eth.block_number)
         assert isinstance(code, HexBytes)
         assert len(code) > 0
 
@@ -418,7 +515,7 @@ class EthModuleTest:
             'to': unlocked_account,
             'value': Wei(1),
             'gas': Wei(21000),
-            'gasPrice': web3.eth.gasPrice,
+            'gasPrice': web3.eth.gas_price,
             'nonce': Nonce(0),
         }
         result = web3.eth.signTransaction(txn_params)
@@ -439,7 +536,7 @@ class EthModuleTest:
                 'to': 'unlocked-account.eth',
                 'value': Wei(1),
                 'gas': Wei(21000),
-                'gasPrice': web3.eth.gasPrice,
+                'gasPrice': web3.eth.gas_price,
                 'nonce': Nonce(0),
             }
             result = web3.eth.signTransaction(txn_params)
@@ -460,7 +557,7 @@ class EthModuleTest:
             'to': unlocked_account,
             'value': Wei(1),
             'gas': Wei(21000),
-            'gasPrice': web3.eth.gasPrice,
+            'gasPrice': web3.eth.gas_price,
         }
 
         with pytest.raises(InvalidAddress):
@@ -479,10 +576,10 @@ class EthModuleTest:
             'to': unlocked_account_dual_type,
             'value': Wei(1),
             'gas': Wei(21000),
-            'gasPrice': web3.eth.gasPrice,
+            'gasPrice': web3.eth.gas_price,
         }
         txn_hash = web3.eth.sendTransaction(txn_params)
-        txn = web3.eth.getTransaction(txn_hash)
+        txn = web3.eth.get_transaction(txn_hash)
 
         assert is_same_address(txn['from'], cast(ChecksumAddress, txn_params['from']))
         assert is_same_address(txn['to'], cast(ChecksumAddress, txn_params['to']))
@@ -499,11 +596,11 @@ class EthModuleTest:
             'value': Wei(1),
             'gas': Wei(21000),
             # Increased gas price to ensure transaction hash different from other tests
-            'gasPrice': Wei(web3.eth.gasPrice * 3),
+            'gasPrice': Wei(web3.eth.gas_price * 3),
             'nonce': web3.eth.getTransactionCount(unlocked_account),
         }
         txn_hash = web3.eth.sendTransaction(txn_params)
-        txn = web3.eth.getTransaction(txn_hash)
+        txn = web3.eth.get_transaction(txn_hash)
 
         assert is_same_address(txn['from'], cast(ChecksumAddress, txn_params['from']))
         assert is_same_address(txn['to'], cast(ChecksumAddress, txn_params['to']))
@@ -520,13 +617,13 @@ class EthModuleTest:
             'to': unlocked_account_dual_type,
             'value': Wei(1),
             'gas': Wei(21000),
-            'gasPrice': web3.eth.gasPrice,
+            'gasPrice': web3.eth.gas_price,
         }
         txn_hash = web3.eth.sendTransaction(txn_params)
 
-        txn_params['gasPrice'] = Wei(web3.eth.gasPrice * 2)
+        txn_params['gasPrice'] = Wei(web3.eth.gas_price * 2)
         replace_txn_hash = web3.eth.replaceTransaction(txn_hash, txn_params)
-        replace_txn = web3.eth.getTransaction(replace_txn_hash)
+        replace_txn = web3.eth.get_transaction(replace_txn_hash)
 
         assert is_same_address(replace_txn['from'], cast(ChecksumAddress, txn_params['from']))
         assert is_same_address(replace_txn['to'], cast(ChecksumAddress, txn_params['to']))
@@ -542,7 +639,7 @@ class EthModuleTest:
             'to': unlocked_account_dual_type,
             'value': Wei(1),
             'gas': Wei(21000),
-            'gasPrice': web3.eth.gasPrice,
+            'gasPrice': web3.eth.gas_price,
         }
         with pytest.raises(TransactionNotFound):
             web3.eth.replaceTransaction(
@@ -558,12 +655,12 @@ class EthModuleTest:
             'to': unlocked_account_dual_type,
             'value': Wei(1),
             'gas': Wei(21000),
-            'gasPrice': web3.eth.gasPrice,
+            'gasPrice': web3.eth.gas_price,
         }
         txn_hash = web3.eth.sendTransaction(txn_params)
         web3.eth.waitForTransactionReceipt(txn_hash)
 
-        txn_params['gasPrice'] = Wei(web3.eth.gasPrice * 2)
+        txn_params['gasPrice'] = Wei(web3.eth.gas_price * 2)
         with pytest.raises(ValueError, match="Supplied transaction with hash"):
             web3.eth.replaceTransaction(txn_hash, txn_params)
 
@@ -575,12 +672,12 @@ class EthModuleTest:
             'to': unlocked_account,
             'value': Wei(1),
             'gas': Wei(21000),
-            'gasPrice': web3.eth.gasPrice,
+            'gasPrice': web3.eth.gas_price,
         }
         txn_hash = web3.eth.sendTransaction(txn_params)
-        txn = web3.eth.getTransaction(txn_hash)
+        txn = web3.eth.get_transaction(txn_hash)
 
-        txn_params['gasPrice'] = Wei(web3.eth.gasPrice * 2)
+        txn_params['gasPrice'] = Wei(web3.eth.gas_price * 2)
         txn_params['nonce'] = Nonce(txn['nonce'] + 1)
         with pytest.raises(ValueError):
             web3.eth.replaceTransaction(txn_hash, txn_params)
@@ -615,7 +712,7 @@ class EthModuleTest:
 
         txn_params.pop('gasPrice')
         replace_txn_hash = web3.eth.replaceTransaction(txn_hash, txn_params)
-        replace_txn = web3.eth.getTransaction(replace_txn_hash)
+        replace_txn = web3.eth.get_transaction(replace_txn_hash)
 
         assert replace_txn['gasPrice'] == 12  # minimum gas price
 
@@ -638,7 +735,7 @@ class EthModuleTest:
 
         txn_params.pop('gasPrice')
         replace_txn_hash = web3.eth.replaceTransaction(txn_hash, txn_params)
-        replace_txn = web3.eth.getTransaction(replace_txn_hash)
+        replace_txn = web3.eth.get_transaction(replace_txn_hash)
         assert replace_txn['gasPrice'] == 20  # Strategy provides higher gas price
 
     def test_eth_replaceTransaction_gas_price_defaulting_strategy_lower(
@@ -660,7 +757,7 @@ class EthModuleTest:
 
         txn_params.pop('gasPrice')
         replace_txn_hash = web3.eth.replaceTransaction(txn_hash, txn_params)
-        replace_txn = web3.eth.getTransaction(replace_txn_hash)
+        replace_txn = web3.eth.get_transaction(replace_txn_hash)
         # Strategy provices lower gas price - minimum preferred
         assert replace_txn['gasPrice'] == 12
 
@@ -672,14 +769,14 @@ class EthModuleTest:
             'to': unlocked_account,
             'value': Wei(1),
             'gas': Wei(21000),
-            'gasPrice': web3.eth.gasPrice,
+            'gasPrice': web3.eth.gas_price,
         }
         txn_hash = web3.eth.sendTransaction(txn_params)
 
         modified_txn_hash = web3.eth.modifyTransaction(
             txn_hash, gasPrice=(cast(int, txn_params['gasPrice']) * 2), value=2
         )
-        modified_txn = web3.eth.getTransaction(modified_txn_hash)
+        modified_txn = web3.eth.get_transaction(modified_txn_hash)
 
         assert is_same_address(modified_txn['from'], cast(ChecksumAddress, txn_params['from']))
         assert is_same_address(modified_txn['to'], cast(ChecksumAddress, txn_params['to']))
@@ -748,7 +845,8 @@ class EthModuleTest:
         revert_contract: "Contract",
         unlocked_account: ChecksumAddress,
     ) -> None:
-        with pytest.raises(SolidityError, match='execution reverted: Function has been reverted'):
+        with pytest.raises(ContractLogicError,
+                           match='execution reverted: Function has been reverted'):
             txn_params = revert_contract._prepare_transaction(
                 fn_name="revertWithMessage",
                 transaction={
@@ -758,13 +856,30 @@ class EthModuleTest:
             )
             web3.eth.call(txn_params)
 
+    def test_eth_call_revert_without_msg(
+        self,
+        web3: "Web3",
+        revert_contract: "Contract",
+        unlocked_account: ChecksumAddress,
+    ) -> None:
+        with pytest.raises(ContractLogicError, match="execution reverted"):
+            txn_params = revert_contract._prepare_transaction(
+                fn_name="revertWithoutMessage",
+                transaction={
+                    "from": unlocked_account,
+                    "to": revert_contract.address,
+                },
+            )
+            web3.eth.call(txn_params)
+
     def test_eth_estimateGas_revert_with_msg(
         self,
         web3: "Web3",
         revert_contract: "Contract",
         unlocked_account: ChecksumAddress,
     ) -> None:
-        with pytest.raises(SolidityError, match='execution reverted: Function has been reverted'):
+        with pytest.raises(ContractLogicError,
+                           match='execution reverted: Function has been reverted'):
             txn_params = revert_contract._prepare_transaction(
                 fn_name="revertWithMessage",
                 transaction={
@@ -774,6 +889,22 @@ class EthModuleTest:
             )
             web3.eth.estimateGas(txn_params)
 
+    def test_eth_estimateGas_revert_without_msg(
+        self,
+        web3: "Web3",
+        revert_contract: "Contract",
+        unlocked_account: ChecksumAddress,
+    ) -> None:
+        with pytest.raises(ContractLogicError, match="execution reverted"):
+            txn_params = revert_contract._prepare_transaction(
+                fn_name="revertWithoutMessage",
+                transaction={
+                    "from": unlocked_account,
+                    "to": revert_contract.address,
+                },
+            )
+            web3.eth.estimateGas(txn_params)
+
     def test_eth_estimateGas(
         self, web3: "Web3", unlocked_account_dual_type: ChecksumAddress
     ) -> None:
@@ -796,90 +927,135 @@ class EthModuleTest:
         assert is_integer(gas_estimate)
         assert gas_estimate > 0
 
+    def test_eth_getBlock_deprecated(
+        self, web3: "Web3", empty_block: BlockData
+    ) -> None:
+        with pytest.warns(DeprecationWarning, match="getBlock is deprecated in favor of get_block"):
+            block = web3.eth.getBlock(empty_block['hash'])
+        assert block['hash'] == empty_block['hash']
+
     def test_eth_getBlockByHash(
         self, web3: "Web3", empty_block: BlockData
     ) -> None:
-        block = web3.eth.getBlock(empty_block['hash'])
+        block = web3.eth.get_block(empty_block['hash'])
         assert block['hash'] == empty_block['hash']
 
     def test_eth_getBlockByHash_not_found(
         self, web3: "Web3", empty_block: BlockData
     ) -> None:
         with pytest.raises(BlockNotFound):
-            web3.eth.getBlock(UNKNOWN_HASH)
+            web3.eth.get_block(UNKNOWN_HASH)
 
     def test_eth_getBlockByHash_pending(
         self, web3: "Web3"
     ) -> None:
-        block = web3.eth.getBlock('pending')
+        block = web3.eth.get_block('pending')
         assert block['hash'] is None
 
     def test_eth_getBlockByNumber_with_integer(
         self, web3: "Web3", empty_block: BlockData
     ) -> None:
-        block = web3.eth.getBlock(empty_block['number'])
+        block = web3.eth.get_block(empty_block['number'])
+        assert block['number'] == empty_block['number']
+
+    def test_eth_getBlockByNumber_with_integer_deprecated(
+        self, web3: "Web3", empty_block: BlockData
+    ) -> None:
+        with pytest.warns(DeprecationWarning, match="getBlock is deprecated in favor of get_block"):
+            block = web3.eth.getBlock(empty_block['number'])
         assert block['number'] == empty_block['number']
 
     def test_eth_getBlockByNumber_latest(
         self, web3: "Web3", empty_block: BlockData
     ) -> None:
-        current_block_number = web3.eth.blockNumber
-        block = web3.eth.getBlock('latest')
+        current_block_number = web3.eth.block_number
+        block = web3.eth.get_block('latest')
         assert block['number'] == current_block_number
 
     def test_eth_getBlockByNumber_not_found(
         self, web3: "Web3", empty_block: BlockData
     ) -> None:
         with pytest.raises(BlockNotFound):
-            web3.eth.getBlock(BlockNumber(12345))
+            web3.eth.get_block(BlockNumber(12345))
 
     def test_eth_getBlockByNumber_pending(
         self, web3: "Web3", empty_block: BlockData
     ) -> None:
-        current_block_number = web3.eth.blockNumber
-        block = web3.eth.getBlock('pending')
+        current_block_number = web3.eth.block_number
+        block = web3.eth.get_block('pending')
         assert block['number'] == current_block_number + 1
 
     def test_eth_getBlockByNumber_earliest(
         self, web3: "Web3", empty_block: BlockData
     ) -> None:
-        genesis_block = web3.eth.getBlock(BlockNumber(0))
-        block = web3.eth.getBlock('earliest')
+        genesis_block = web3.eth.get_block(BlockNumber(0))
+        block = web3.eth.get_block('earliest')
         assert block['number'] == 0
         assert block['hash'] == genesis_block['hash']
 
     def test_eth_getBlockByNumber_full_transactions(
         self, web3: "Web3", block_with_txn: BlockData
     ) -> None:
-        block = web3.eth.getBlock(block_with_txn['number'], True)
+        block = web3.eth.get_block(block_with_txn['number'], True)
         transaction = block['transactions'][0]
         assert transaction['hash'] == block_with_txn['transactions'][0]  # type: ignore
 
     def test_eth_getTransactionByHash(
         self, web3: "Web3", mined_txn_hash: HexStr
     ) -> None:
-        transaction = web3.eth.getTransaction(mined_txn_hash)
+        transaction = web3.eth.get_transaction(mined_txn_hash)
+        assert is_dict(transaction)
+        assert transaction['hash'] == HexBytes(mined_txn_hash)
+
+    def test_eth_getTransactionByHash_deprecated(
+        self, web3: "Web3", mined_txn_hash: HexStr
+    ) -> None:
+        with pytest.warns(DeprecationWarning,
+                          match='getTransaction is deprecated in favor of get_transaction'):
+            transaction = web3.eth.getTransaction(mined_txn_hash)
         assert is_dict(transaction)
         assert transaction['hash'] == HexBytes(mined_txn_hash)
 
     def test_eth_getTransactionByHash_contract_creation(
         self, web3: "Web3", math_contract_deploy_txn_hash: HexStr
     ) -> None:
-        transaction = web3.eth.getTransaction(math_contract_deploy_txn_hash)
+        transaction = web3.eth.get_transaction(math_contract_deploy_txn_hash)
         assert is_dict(transaction)
         assert transaction['to'] is None, "to field is %r" % transaction['to']
 
     def test_eth_getTransactionByBlockHashAndIndex(
         self, web3: "Web3", block_with_txn: BlockData, mined_txn_hash: HexStr
     ) -> None:
-        transaction = web3.eth.getTransactionByBlock(block_with_txn['hash'], 0)
+        transaction = web3.eth.get_transaction_by_block(block_with_txn['hash'], 0)
+        assert is_dict(transaction)
+        assert transaction['hash'] == HexBytes(mined_txn_hash)
+
+    def test_eth_getTransactionByBlockHashAndIndex_deprecated(
+        self, web3: "Web3", block_with_txn: BlockData, mined_txn_hash: HexStr
+    ) -> None:
+        with pytest.warns(
+            DeprecationWarning,
+            match='getTransactionByBlock is deprecated in favor of get_transaction_by_block'
+        ):
+            transaction = web3.eth.getTransactionByBlock(block_with_txn['hash'], 0)
         assert is_dict(transaction)
         assert transaction['hash'] == HexBytes(mined_txn_hash)
 
     def test_eth_getTransactionByBlockNumberAndIndex(
         self, web3: "Web3", block_with_txn: BlockData, mined_txn_hash: HexStr
     ) -> None:
-        transaction = web3.eth.getTransactionByBlock(block_with_txn['number'], 0)
+        transaction = web3.eth.get_transaction_by_block(block_with_txn['number'], 0)
+        assert is_dict(transaction)
+        assert transaction['hash'] == HexBytes(mined_txn_hash)
+
+    def test_eth_getTransactionByBlockNumberAndIndex_deprecated(
+        self, web3: "Web3", block_with_txn: BlockData, mined_txn_hash: HexStr
+    ) -> None:
+        with pytest.warns(
+            DeprecationWarning,
+            match='getTransactionByBlock is deprecated in favor of get_transaction_by_block'
+        ):
+            transaction = web3.eth.getTransactionByBlock(block_with_txn['number'], 0)
         assert is_dict(transaction)
         assert transaction['hash'] == HexBytes(mined_txn_hash)
 
@@ -904,7 +1080,7 @@ class EthModuleTest:
             'to': unlocked_account_dual_type,
             'value': Wei(1),
             'gas': Wei(21000),
-            'gasPrice': web3.eth.gasPrice,
+            'gasPrice': web3.eth.gas_price,
         })
         with pytest.raises(TransactionNotFound):
             web3.eth.getTransactionReceipt(txn_hash)
@@ -1121,7 +1297,7 @@ class EthModuleTest:
     def test_eth_call_old_contract_state(
         self, web3: "Web3", math_contract: "Contract", unlocked_account: ChecksumAddress
     ) -> None:
-        start_block = web3.eth.getBlock('latest')
+        start_block = web3.eth.get_block('latest')
         block_num = start_block["number"]
         block_hash = start_block["hash"]
 
