@@ -633,9 +633,9 @@ class ContractConstructor:
             self.check_forbidden_keys_in_transaction(estimate_gas_transaction,
                                                      ["data", "to"])
 
-        if self.web3.eth.defaultAccount is not empty:
-            # type ignored b/c check prevents an empty defaultAccount
-            estimate_gas_transaction.setdefault('from', self.web3.eth.defaultAccount)  # type: ignore # noqa: E501
+        if self.web3.eth.default_account is not empty:
+            # type ignored b/c check prevents an empty default_account
+            estimate_gas_transaction.setdefault('from', self.web3.eth.default_account)  # type: ignore # noqa: E501
 
         estimate_gas_transaction['data'] = self.data_in_transaction
 
@@ -652,9 +652,9 @@ class ContractConstructor:
             self.check_forbidden_keys_in_transaction(transact_transaction,
                                                      ["data", "to"])
 
-        if self.web3.eth.defaultAccount is not empty:
-            # type ignored b/c check prevents an empty defaultAccount
-            transact_transaction.setdefault('from', self.web3.eth.defaultAccount)  # type: ignore
+        if self.web3.eth.default_account is not empty:
+            # type ignored b/c check prevents an empty default_account
+            transact_transaction.setdefault('from', self.web3.eth.default_account)  # type: ignore
 
         transact_transaction['data'] = self.data_in_transaction
 
@@ -674,9 +674,9 @@ class ContractConstructor:
             self.check_forbidden_keys_in_transaction(built_transaction,
                                                      ["data", "to"])
 
-        if self.web3.eth.defaultAccount is not empty:
-            # type ignored b/c check prevents an empty defaultAccount
-            built_transaction.setdefault('from', self.web3.eth.defaultAccount)  # type: ignore
+        if self.web3.eth.default_account is not empty:
+            # type ignored b/c check prevents an empty default_account
+            built_transaction.setdefault('from', self.web3.eth.default_account)  # type: ignore
 
         built_transaction['data'] = self.data_in_transaction
         built_transaction['to'] = Address(b'')
@@ -933,9 +933,9 @@ class ContractFunction:
 
         if self.address:
             call_transaction.setdefault('to', self.address)
-        if self.web3.eth.defaultAccount is not empty:
-            # type ignored b/c check prevents an empty defaultAccount
-            call_transaction.setdefault('from', self.web3.eth.defaultAccount)  # type: ignore
+        if self.web3.eth.default_account is not empty:
+            # type ignored b/c check prevents an empty default_account
+            call_transaction.setdefault('from', self.web3.eth.default_account)  # type: ignore
 
         if 'to' not in call_transaction:
             if isinstance(self, type):
@@ -975,9 +975,9 @@ class ContractFunction:
 
         if self.address is not None:
             transact_transaction.setdefault('to', self.address)
-        if self.web3.eth.defaultAccount is not empty:
-            # type ignored b/c check prevents an empty defaultAccount
-            transact_transaction.setdefault('from', self.web3.eth.defaultAccount)  # type: ignore
+        if self.web3.eth.default_account is not empty:
+            # type ignored b/c check prevents an empty default_account
+            transact_transaction.setdefault('from', self.web3.eth.default_account)  # type: ignore
 
         if 'to' not in transact_transaction:
             if isinstance(self, type):
@@ -1017,9 +1017,9 @@ class ContractFunction:
 
         if self.address:
             estimate_gas_transaction.setdefault('to', self.address)
-        if self.web3.eth.defaultAccount is not empty:
-            # type ignored b/c check prevents an empty defaultAccount
-            estimate_gas_transaction.setdefault('from', self.web3.eth.defaultAccount)  # type: ignore # noqa: E501
+        if self.web3.eth.default_account is not empty:
+            # type ignored b/c check prevents an empty default_account
+            estimate_gas_transaction.setdefault('from', self.web3.eth.default_account)  # type: ignore # noqa: E501
 
         if 'to' not in estimate_gas_transaction:
             if isinstance(self, type):
@@ -1261,8 +1261,8 @@ class ContractEvent:
 
         .. code-block:: python
 
-            from = max(mycontract.web3.eth.blockNumber - 10, 1)
-            to = mycontract.web3.eth.blockNumber
+            from = max(mycontract.web3.eth.block_number - 10, 1)
+            to = mycontract.web3.eth.block_number
 
             events = mycontract.events.Transfer.getLogs(fromBlock=from, toBlock=to)
 
@@ -1510,7 +1510,7 @@ def call_contract_function(
         # eth-abi-utils
         is_missing_code_error = (
             return_data in ACCEPTABLE_EMPTY_STRINGS
-            and web3.eth.getCode(address) in ACCEPTABLE_EMPTY_STRINGS)
+            and web3.eth.get_code(address) in ACCEPTABLE_EMPTY_STRINGS)
         if is_missing_code_error:
             msg = (
                 "Could not transact with/call contract function, is contract "
